<?php

// css読み込み順序
function theme_enqueue_styles() {
	wp_enqueue_style('child-style', get_stylesheet_directory_uri() . '/style.css', array('cambropachycope'));
}
add_action('wp_enqueue_scripts', 'theme_enqueue_styles');

// 絵文字の画像の置き換えはしない（絵文字投稿無し）
function disable_emoji() {
     remove_action( 'wp_head', 'print_emoji_detection_script', 7 );
     remove_action( 'admin_print_scripts', 'print_emoji_detection_script' );
     remove_action( 'wp_print_styles', 'print_emoji_styles' );
     remove_action( 'admin_print_styles', 'print_emoji_styles' );
     remove_filter( 'the_content_feed', 'wp_staticize_emoji' );
     remove_filter( 'comment_text_rss', 'wp_staticize_emoji' );
     remove_filter( 'wp_mail', 'wp_staticize_emoji_for_email' );
}
add_action( 'init', 'disable_emoji' );

// カスタム投稿タイプeventを追加
function create_post_type_event() {
	register_post_type('event',  // カスタム投稿タイプ名
		array(
			'labels' => array(
				'name' => __('イベント開催予定'),
				'singular_name' => __('イベント開催予定')
			),
			'public' => true,
			'has_archive' => true,  // アーカイブページを持つ
			'menu_position' => 5,  // 管理画面のメニュー順位
			'supports' => array('title', 'editor'),
		)
	);
	register_taxonomy(
		'event_cat',  // タクソノミーの名前
		'event',  // 使用するカスタム投稿タイプ名
		array(
			'hierarchical' => true,
			'update_count_callback' => '_update_post_term_count',
			'label' => 'イベント開催予定カテゴリー',
			'singular_label' => 'イベント開催予定カテゴリー',
			'public' => true,
			'show_ui' => true,
			'rewrite' => array(
				'with_front' => false
			)
		)
	);
	register_taxonomy(
		'event_tag',  // タクソノミーの名前
		'event',  // 使用するカスタム投稿タイプ名
		array(
			'hierarchical' => false,
			'update_count_callback' => '_update_post_term_count',
			'label' => 'イベント開催予定タグ',
			'singular_label' => 'イベント開催予定タグ',
			'public' => true,
			'show_ui' => true,
			'rewrite' => array(
				'with_front' => false
			)
		)
	);
}
add_action('init', 'create_post_type_event');

/* イベントカテゴリの件数と並び順 */
function event_post($query) {
	if (is_admin() || ! $query->is_main_query()) return;
	if ($query->is_post_type_archive('event')) {
		$query->set( 'posts_per_page', 8 ); /* 件数 */
		$query->set( 'meta_key', 'date_start' ); /* カスタムフィールド名 */
		$query->set( 'orderby', 'meta_value_num' );
		$query->set( 'order', 'DESC' );
		return;
	}
}
add_action('pre_get_posts', 'event_post');

/* アーカイブスのタイトル編集 */
add_filter( 'get_the_archive_title', function ($title) {
    if ( is_category() ) {
            $title = single_cat_title( '', false );
        } elseif ( is_tag() ) {
            $title = single_tag_title( '', false );
        } elseif ( is_post_type_archive() ) {
          $title = post_type_archive_title( '', false );
        }
    return $title;
});

/* 「投稿」を「ニュース」に変更 */
function change_post_menu_label() {
	global $menu;
	global $submenu;
	$menu[5][0] = 'ニュース';
	$submenu['edit.php'][5][0] = 'ニュース一覧';
	$submenu['edit.php'][10][0] = '新しいニュース';
	$submenu['edit.php'][16][0] = 'タグ';
}
function change_post_object_label() {
	global $wp_post_types;
	$labels = &$wp_post_types['post']->labels;
	$labels->name = 'ニュース';
	$labels->singular_name = 'ニュース';
	$labels->add_new = _x('追加', 'ニュース');
	$labels->add_new_item = 'ニュースの新規追加';
	$labels->edit_item = 'ニュースの編集';
	$labels->new_item = '新規ニュース';
	$labels->view_item = 'ニュースを表示';
	$labels->search_items = 'ニュースを検索';
	$labels->not_found = '記事が見つかりませんでした';
	$labels->not_found_in_trash = 'ゴミ箱に記事は見つかりませんでした';
}
add_action('init', 'change_post_object_label');
add_action('admin_menu', 'change_post_menu_label');

require get_stylesheet_directory() . '/inc/postnav.php';

/* カスタムメニュー
[menu name="カスタムメニュー名"]で固定ページ内表示 */
function print_menu_shortcode($atts, $content = null) {
    extract(shortcode_atts(array( 'name' => null, ), $atts));
    return wp_nav_menu( array( 'menu' => $name, 'container_class' => 'embedded-menu', 'echo' => false ) );
}
add_shortcode('menu', 'print_menu_shortcode');

/* 子ページに親ページのタイトルを表示 */
function ps_get_root_page( $cur_post, $cnt = 0 ) {
	if ( $cnt > 100 ) { return false; }
	$cnt++;
	if ( $cur_post->post_parent == 0 ) {
		$root_page = $cur_post;
	} else {
		$root_page = ps_get_root_page( get_post( $cur_post->post_parent ), $cnt );
	}
	return $root_page;
}
