<?php
if ( ! isset( $content_width ) ) $content_width = 640;

add_theme_support( 'post-thumbnails' );
add_image_size( 'banner', 230, 9999, false );
add_image_size( 'banner-x2', 230, 9999, false );
add_image_size( 'slide', 960, 440, true );
set_post_thumbnail_size( 'thumbnail' );

/**
 * wp_head()から余計な項目を削除
 */
remove_action('wp_head', 'wp_generator');
remove_action('wp_head', 'rsd_link');
remove_action('wp_head', 'wlwmanifest_link');
remove_action('wp_head', 'feed_links', 2);
remove_action('wp_head', 'feed_links_extra', 3);

/**
 * フロント側で用いるCSSやjsの登録。
 * wp_enqueue_style()とwp_enqueue_script()とで登録する
 *
 * @see inc/theme-options/theme-options.php パッケージ標準のPikaiaとHallucigeniaを登録
 */
add_action( 'wp_enqueue_scripts', 'enqueue_theme_styles', 100 );
function enqueue_theme_styles() {
	wp_enqueue_style( 'style', get_template_directory_uri() . '/style.min.css', '', '1.0' );
	wp_enqueue_style( 'colorbox.css', get_template_directory_uri() . '/css/colorbox.css', '', '1.0' );
	wp_enqueue_style( 'flexslider.css', get_template_directory_uri() . '/css/flexslider.css', '', '1.0' );

	wp_enqueue_script( 'jquery' );
	wp_enqueue_script( 'colorbox', get_template_directory_uri() . '/js/jquery.colorbox-min.js', 'jquery', '1.0', true );
	wp_enqueue_script( 'flexslider', get_template_directory_uri() . '/js/jquery.flexslider-min.js', 'jquery', '1.0', true );
	wp_enqueue_script( 'functions', get_template_directory_uri() . '/js/functions.js', 'jquery', '1.0', true );
}

/**
 * 画像のaタグにクラスを追加
 */
add_filter( 'image_send_to_editor', 'add_media_class' );
function add_media_class( $html ) {
	$class = 'extension';
	return str_replace( '<a ', '<a class="'. $class. '" ', $html );
}

/**
 * 製作時によくつかうスニペット達
 */
function call_page_link($page_ID, $class = ''){
	echo '<a class="'.$class.'" href="'.get_page_link($page_ID).'">'.get_the_title($page_ID).'</a>';
}
function the_img_path($file_name){
	echo get_template_directory_uri().'/img/'.$file_name;
}
function the_img($file_name, $class_name = ''){
	echo '<img class="'.$class_name.'" src="'.get_template_directory_uri().'/img/'.$file_name.'">';
}
function get_img_path($file_name){
	return get_template_directory_uri().'/img/'.$file_name;
}
function get_img($file_name, $class_name = ''){
	return '<img class="'.$class_name.'" src="'.get_template_directory_uri().'/img/'.$file_name.'">';
}


/**
 * 日英の言語切り替えでよくつかう定義と関数
 */
if ( get_bloginfo('language') == 'ja' ) :
	define('chk_lang', 'jp');
else :
	define('chk_lang', 'en');
endif;

function switch_lang($jp, $en){
	if ( chk_lang == 'jp' ):
		echo $jp;
	else:
		echo $en;
	endif;
}
function get_switch_lang($jp, $en){
	if ( chk_lang == 'jp' ):
		return $jp;
	else:
		return $en;
	endif;
}

/**
 * 管理者「以外」の編集画面をカスタマイズ
 */
if ( ! current_user_can("administrator") ):
	add_action('admin_menu', 'remove_menus' );
	add_action('admin_menu', 'add_admin_menu_menus');
	add_action('admin_init', 'change_editor');
	// add_action('admin_init', 'remove_dashboard_widgets');  // by ST Yanagida 2016-03-07
	add_filter('custom_menu_order', 'custom_menu_order'); // Activate custom_menu_order
	add_filter('menu_order', 'custom_menu_order');
endif;

// 不要なメニュー項目を削除
function remove_menus(){
	remove_menu_page( 'themes.php' );
	remove_menu_page( 'edit-comments.php' );
	remove_menu_page( 'profile.php' );
	remove_menu_page( 'users.php' );
	remove_menu_page( 'tools.php' );
	remove_menu_page( 'options-general.php' );
}

// メニュー項目に「メニュー」を追加
// @uses get_switch_lang()
function add_admin_menu_menus(){
	add_menu_page(
		get_switch_lang('メニュー', 'Menus'),
		get_switch_lang('メニュー', 'Menus'),
		'edit_theme_options',
		'nav-menus.php'
		);
}

// 「編集者」にメニュー編集の権限を追加。
function change_editor(){
	$role = get_role('editor');
	$role->add_cap('edit_theme_options');
}

// ダッシュボードから不要なウィジェットを削除
function remove_dashboard_widgets() {
	remove_meta_box( 'dashboard_incoming_links', 'dashboard', 'normal' );
	remove_meta_box( 'dashboard_plugins', 'dashboard', 'normal' );
	remove_meta_box( 'dashboard_primary', 'dashboard', 'normal' );
	remove_meta_box( 'dashboard_secondary', 'dashboard', 'normal' );
	remove_meta_box( 'dashboard_quick_press', 'dashboard', 'side' );
	remove_meta_box( 'dashboard_recent_drafts', 'dashboard', 'side' );
	remove_meta_box( 'dashboard_recent_comments', 'dashboard', 'normal' );
	// remove_meta_box( 'dashboard_right_now', 'dashboard', 'normal' );
	remove_meta_box( 'dashboard_activity', 'dashboard', 'normal');//since 3.8
}

// 管理画面のサイドメニューを並べ替え
function custom_menu_order($menu_ord) {
	if ( ! $menu_ord ) return true;

	return array(
		'index.php', // Dashboard
		'separator1', // First separator
		'edit.php', // Posts
		'edit.php?post_type=page', // Pages
		'upload.php', // Media
		'separator2', // Second separator
		'edit.php?post_type=banners', // banner
		'nav-menus.php',
		);
}


/**
 * local navigation
 * 現在の固定ページの、兄弟、子、甥・姪を表示
 * 親ページがない（トップレベル）の場合は何もしない
 */
function local_navigation(){
	global $post;
	if ( is_page() and ! is_front_page() ):

		$ancestors = get_ancestors($post->ID, 'page');
		if ( empty($ancestors) ) return; // 親ページがない（トップレベル）場合はreturn

		$parent_id    = $ancestors[0];
		$parent_title = get_the_title($parent_id);

		echo '<div class="local-nav">';
		echo '<h3>In This Section</h3>';
		echo '<ul>';
		wp_list_pages(array(
			'child_of'    => $parent_id,
			'title_li'    => '',
			'sort_column' => 'menu_order',
			));
		echo '</ul>';
		echo '</div>';

	endif;
} // local_navigation

function get_archives_by_fiscal_year( $args = '' ) {
    global $wpdb, $wp_locale;
    $defaults = array (
        'post_type' => 'post',
        'limit' => '',
        'format' => 'html',
        'before' => '',
        'after' => '',
        'show_post_count' => false,
        'echo' => 1
    );
    $r = wp_parse_args( $args, $defaults );
    extract ( $r, EXTR_SKIP );
    if ( '' != $limit ) {
        $limit = absint( $limit );
        $limit = ' LIMIT ' . $limit;
    }
    $arcresults = (array) $wpdb->get_results(
        "SELECT YEAR(ADDDATE(post_date, INTERVAL -3 MONTH)) AS `year`, COUNT(ID) AS `posts`
        FROM $wpdb->posts
        WHERE post_type = '$post_type' AND post_status = 'publish'
        GROUP BY YEAR(ADDDATE(post_date, INTERVAL -3 MONTH))
        ORDER BY post_date DESC
        $limit"
    );
    return $arcresults;
}

/*  ナビゲーションを読み込むウイジェットを追加 */
register_sidebar(array(
	'name' => 'Sidebar' ,
	'id' => 'sidebar' ,
	'before_widget' => '<div class="widget">',
	'after_widget' => '</div>',
	'before_title' => '',
	'after_title' => ''
));

/* 「投稿」を「ニュース」に変更 */
function change_post_menu_label() {
	global $menu;
	global $submenu;
	$menu[5][0] = 'News';
	$submenu['edit.php'][5][0] = 'News一覧';
	$submenu['edit.php'][10][0] = '新しいNews';
	$submenu['edit.php'][16][0] = 'タグ';
}
function change_post_object_label() {
	global $wp_post_types;
	$labels = &$wp_post_types['post']->labels;
	$labels->name = 'News';
	$labels->singular_name = 'News';
	$labels->add_new = _x('追加', 'News');
	$labels->add_new_item = 'Newsの新規追加';
	$labels->edit_item = 'Newsの編集';
	$labels->new_item = '新規News';
	$labels->view_item = 'Newsを表示';
	$labels->search_items = 'Newsを検索';
	$labels->not_found = '記事が見つかりませんでした';
	$labels->not_found_in_trash = 'ゴミ箱に記事は見つかりませんでした';
}
add_action('init', 'change_post_object_label');
add_action('admin_menu', 'change_post_menu_label');

// 絵文字の画像の置き換えはしない（絵文字投稿無し）
function disable_emoji() {
     remove_action( 'wp_head', 'print_emoji_detection_script', 7 );
     remove_action( 'admin_print_scripts', 'print_emoji_detection_script' );
     remove_action( 'wp_print_styles', 'print_emoji_styles' );
     remove_action( 'admin_print_styles', 'print_emoji_styles' );
     remove_filter( 'the_content_feed', 'wp_staticize_emoji' );
     remove_filter( 'comment_text_rss', 'wp_staticize_emoji' );
     remove_filter( 'wp_mail', 'wp_staticize_emoji_for_email' );
}
add_action( 'init', 'disable_emoji' );

// カスタム投稿タイプeventを追加
function create_post_type_event() {
	register_post_type('event',  // カスタム投稿タイプ名
		array(
			'labels' => array(
				'name' => __('イベント'),
				'singular_name' => __('イベント')
			),
			'public' => true,
			'has_archive' => true,  // アーカイブページを持つ
			'menu_position' => 5,  // 管理画面のメニュー順位
			'supports' => array('title', 'editor'),
		)
	);
	register_taxonomy(
		'event_cat',  // タクソノミーの名前
		'event',  // 使用するカスタム投稿タイプ名
		array(
			'hierarchical' => true,
			'update_count_callback' => '_update_post_term_count',
			'label' => 'イベントカテゴリー',
			'singular_label' => 'イベントカテゴリー',
			'public' => true,
			'show_ui' => true,
			'rewrite' => array(
				'with_front' => false
			)
		)
	);
	register_taxonomy(
		'event_tag',  // タクソノミーの名前
		'event',  // 使用するカスタム投稿タイプ名
		array(
			'hierarchical' => false,
			'update_count_callback' => '_update_post_term_count',
			'label' => 'イベントタグ',
			'singular_label' => 'イベントタグ',
			'public' => true,
			'show_ui' => true,
			'rewrite' => array(
				'with_front' => false
			)
		)
	);
}
add_action('init', 'create_post_type_event');

/* イベントカテゴリの件数と並び順 */
function event_post($query) {
	if (is_admin() || ! $query->is_main_query()) return;
	if ($query->is_post_type_archive('event')) {
		$query->set( 'posts_per_page', 8 ); /* 件数 */
		$query->set( 'meta_key', 'date_start' ); /* カスタムフィールド名 */
		$query->set( 'orderby', 'meta_value_num' );
		$query->set( 'order', 'DESC' );
		return;
	}
}
add_action('pre_get_posts', 'event_post');

require get_stylesheet_directory() . '/inc/postnav.php';

/* カスタムメニュー
[menu name="カスタムメニュー名"]で固定ページ内にメニューを表示 */
function print_menu_shortcode($atts, $content = null) {
    extract(shortcode_atts(array( 'name' => null, ), $atts));
    return wp_nav_menu( array( 'menu' => $name, 'container_class' => 'embedded-menu', 'echo' => false ) );
}
add_shortcode('menu', 'print_menu_shortcode');

/* アーカイブスのタイトル編集 */
add_filter( 'get_the_archive_title', function ($title) {
    if ( is_category() ) {
            $title = single_cat_title( '', false );
        } elseif ( is_tag() ) {
            $title = single_tag_title( '', false );
        } elseif ( is_post_type_archive() ) {
          $title = post_type_archive_title( '', false );
        }
    return $title;
});
