<?php
/**
 * Cambria functions and definitions
 *
 * @package Cambria
 */



if ( ! function_exists( 'st_cambria_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function st_cambria_setup() {
	/*
	 * Make theme available for translation.
	 * Translations can be filed in the /languages/ directory.
	 * If you're building a theme based on Cambria, use a find and replace
	 * to change 'st-cambria' to the name of your theme in all the template files
	 */
	load_theme_textdomain( 'st-cambria', get_template_directory() . '/languages' );

	// This theme uses wp_nav_menu() in one location.
	register_nav_menus( array(
		'primary' => esc_html__( 'Primary Menu', 'st-cambria' ),
	) );

	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support( 'html5', array(
		'search-form',
		'comment-form',
		'comment-list',
		'gallery',
		'caption',
	) );
}
endif; // st_cambria_setup
add_action( 'after_setup_theme', 'st_cambria_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function st_cambria_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'st_cambria_content_width', 640 );
}
add_action( 'after_setup_theme', 'st_cambria_content_width', 0 );


/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require get_template_directory() . '/inc/extras.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
require get_template_directory() . '/inc/jetpack.php';



// ここから下を編集してください



/**
 * 追加関数の登録
 * functions.php（このファイル）　→　underscoresの標準
 * functions-st-cambria.php    →　自分で追加した関数
 */
require get_template_directory() . '/functions-st-cambria.php';

/**
 * テーマオプション画面の追加
 */
require get_template_directory() . '/inc/theme-options/theme-options.php';

/**
 * カスタム投稿「バナー」の追加
 */
require get_template_directory() . '/inc/register-banner/register-banner.php';

/**
 * ショートコードの登録
 */
require get_template_directory() . '/inc/shortcodes/shortcodes.php';

/**
 * パンくずリスト
 */
require get_template_directory() . '/inc/breadcrumb.php';

/**
 * 投稿ウィジェット
 */
require get_template_directory() . '/inc/st-post-widget.php';
