<?php
/**
 * The function for showing breadcrumb
 *
 * @package Cambria
 * @version 2016-03-07
 */


if ( ! function_exists('breadcrumb') ):
	function breadcrumb(){
		$breadcrumb = new ST_cambria_breadcrumb();
		$breadcrumb->output();
	}
endif;

/**
 * breadcrumb class
 */
class ST_cambria_breadcrumb{
	public $content;

	function __construct(){
		$this->content = '';
	}

	/**
	 * 出力
	 * @uses $this->add_li()
	 * @return print $this->content
	 */
	public function output(){
		$this->content .= '<ul class="breadcrumb">';
		$this->add_li( 'Home', home_url(), 'home' ); // Homeへのリンクは必ず追加

		if ( is_404() ) :
			$this->error();
		elseif ( is_home() ) :
			$this->home();
		elseif ( is_search() ) :
			$this->search();
		elseif ( is_tag() ):
			$this->tag();
		elseif ( is_category() ) :
			$this->category();
		elseif ( is_tax() ):
			$this->tax();
		elseif ( is_date() ) :
			$this->date();
		elseif ( is_post_type_archive() ) :
			$this->post_type_archive();
		elseif ( is_single() ) :
			$this->single();
		elseif ( is_page() and ! is_front_page() ) :
			$this->page();
		endif;

		$this->content .= '</ul>';

		echo $this->content;
	}

	/**
	 * クラス内で使う補助用メソッド。バンくずにli要素を追加する。
	 * @param $label
	 * @param $url
	 * @param $class_name
	 * @return none
	 */
	public function add_li($label = '', $url = '', $class_name = ''){
		if ( empty($url) ):
			$this->content .= '<li class="breadcrumb-item '.$class_name.'">'.$label.'</li>';
		else:
			$this->content .= '<li class="breadcrumb-item '.$class_name.'"><a href="'.esc_url($url).'">'.$label.'</a></li>';
		endif;
	}

	/**
	 * 404
	 * @uses add_li()
	 */
	public function error(){
		$this->add_li( '404 Not Found' );
	}

	/**
	 * home
	 * @uses add_li()
	 */
	public function home(){
		$this->add_li( single_post_title('',false));
	}

	/**
	 * search result
	 * @uses add_li()
	 */
	public function search(){
		$this->add_li( 'Searching for '.get_search_query() );
	}

	/**
	 * tag archive
	 * @uses add_li()
	 */
	public function tag(){
		$this->add_li( single_tag_title('', false) );
	}

	/**
	 * category archive
	 * @uses add_li()
	 */
	public function category(){
		global $cat;

		$category = get_category($cat);

		if ( $category->parent != 0 ): // 親カテゴリをさかのぼる
			$ancestors = array_reverse(get_ancestors($category->term_id, 'category'));

			foreach ($ancestors as $ancestor_id) :
				$ancestor = get_category($ancestor_id);
				$this->add_li( $ancestor->name, get_category_link($ancestor_id) ); // 親カテゴリを追加
			endforeach;
		endif;

		$this->add_li( $category->name ); // 現在のカテゴリを最後に追加
	}

	/**
	 * taxonomy archive
	 * @uses add_li()
	 */
	public function tax(){
		$post_type = get_query_var( 'post_type' );
		$object    = get_post_type_object( $post_type );
		$this->add_li( $object->label, get_post_type_archive_link( $object->name ) ); //第一階層にアーカイブページを追加
	}

	/**
	 * yealy, monthly, daily archive
	 * @uses add_li()
	 */
	public function date(){
		list ($yval, $year) = $this->get_year();
		if ( is_year() ):
			$this->add_li( $year );
		elseif ( is_month() ):
			list ($mval, $month) = $this->get_month();
			$this->add_li( $year, get_year_link( $yval ) );
			$this->add_li( $month );
		elseif ( is_day() ):
			list ($mval, $month) = $this->get_month();
			list ($dval, $day) = $this->get_day();
			$this->add_li( $year, get_year_link( $yval ) );
			$this->add_li( $month, get_month_link( $yval, $mval ) );
			$this->add_li( $day );
		endif;
	}

	public function get_year() {
		$val = get_query_var('year');
		if ($val == 0) $val = get_the_time('Y');
		$str = $val . (( chk_lang == 'jp' ) ? '年' : '');
		return array ($val, $str);
	}

	public function get_month() {
		$val = get_query_var('monthnum');
		if ($val == 0) $val = get_the_time('m');
		if (chk_lang == 'jp') {
			$str = $val . '月';
		} else {
			global $wp_locale;
			$str = $wp_locale->get_month_abbrev( $wp_locale->get_month( $val ));
		}
		return array ($val, $str);
	}

	public function get_day() {
		$val = get_query_var('day');
		if ($val == 0) $val = get_the_time('d');
		$str = $val . (( chk_lang == 'jp' ) ? '日' : '');
		return array ($val, $str);
	}

	/**
	 * custom post type archive
	 * @uses add_li()
	 */
	public function post_type_archive(){
		$object = get_post_type_object( get_query_var( 'post_type' ) );
		$this->add_li( $object->label );
	}

	/**
	 * sigle post
	 * @uses add_li()
	 */
	public function single(){
		global $post;

		if ( get_post_type() != 'post' ): // カスタム投稿の場合
			$post_type = get_query_var( 'post_type' );
			$object    = get_post_type_object( $post_type );
			$this->add_li( $object->label, get_post_type_archive_link( $object->name ) ); //第一階層にアーカイブページを追加

			if ( is_post_type_hierarchical( $post_type ) ): // カスタム投稿が階層を持てる場合
				$ancestors = array_reverse( get_ancestors( $post->ID, $post_type ) );

				if ( ! empty($ancestors) ):
					foreach ( $ancestors as $ancestor_id ) :
						$this->add_li( get_the_title($ancestor_id), get_permalink($ancestor_id) );
					endforeach;
				endif;
			endif;

		else: //　投稿の場合
			//　$category = get_the_category( $post->ID );
			//　$this->add_li( $category[0]->name, get_category_link( $category[0]->term_id ) ); // 最初の親カテゴリだけ追加
			$this->add_li( "News" , get_post_type_archive_link( 'post' ) ); //第一階層にアーカイブページを追加
		endif;

		$this->add_li( get_the_title( $post->ID ) ); //最後に自分を追加
	}

	/**
	 * page
	 * @uses add_li()
	 */
	public function page(){
		global $post;
		$ancestors = array_reverse( get_ancestors($post->ID, 'page') );

		if ( ! empty($ancestors) ):
			foreach ( $ancestors as $ancestor_id ) :
				$this->add_li( get_the_title($ancestor_id), get_permalink($ancestor_id) );
			endforeach;
		endif;

		$this->add_li( get_the_title($post->ID) ); //最後に自分を追加
	}

} // class end
