<?php 

/**
 * カスタム投稿のスラッグ
 */
$register_type_name = 'banners';


/**
 * カスタム投稿を登録
 * @uses $register_type_name
 * @uses get_switch_lang()
 */
add_action('init', 'st_cambria_register_banners');
function st_cambria_register_banners() {
	global $register_type_name;

	register_post_type($register_type_name, array(
		'label'           => $register_type_name,
		'description'     => '',
		'public'          => true,
		'show_ui'         => true,
		'show_in_menu'    => true,
		'show_in_nav_menus' => true,
		'exclude_from_search' => 'false',
		'capability_type' => 'page',
		'map_meta_cap'    => true,
		'hierarchical'    => true,
		'rewrite'         => array('slug' => $register_type_name, 'with_front' => true),
		'query_var'       => true,
		'has_archive'     => true,
		'menu_position'   => 75,
		'menu_icon'       => 'dashicons-format-image',
		'supports'        => array('title', 'thumbnail'),
		'labels'          => array(
			'name'               => get_switch_lang('バナー', 'Banners'),
			'singular_name'      => get_switch_lang('バナー', 'Banner'),
			'menu_name'          => get_switch_lang('バナー', 'Banners'),
			'add_new'            => get_switch_lang('新規追加', 'Add New'),
			'add_new_item'       => get_switch_lang('新規バナーを追加', 'Add New Banner'),
			'edit'               => '',
			'edit_item'          => '',
			'new_item'           => get_switch_lang('New Banner', 'New Banner'),
			'view'               => '',
			'view_item'          => '',
			'search_items'       => get_switch_lang('バナーを検索', 'Search Banner'),
			'not_found'          => get_switch_lang('バナーがみつかりませんでした。', 'No Banners Found'),
			'not_found_in_trash' => get_switch_lang('ゴミ箱内にバナーは見つかりませんでした。', 'No Banners Found in Trash'),
			)
		)
	);
};

/**
 * カスタム投稿の記事編集ページにメタボックスを追加
 */
if( isset($_GET['post']) or isset($_POST['post_ID']) or isset($_GET['post_type']) ) :
	add_action('add_meta_boxes', 'st_cambria_add_metabox');
	add_action('save_post', 'st_cambria_update_banner_meta');
endif;

/** 
 * メタボックス登録
 * @uses $register_type_name
 */
function st_cambria_add_metabox() {
	global $register_type_name;
	add_meta_box('url_form', 'URL and Caption', 'st_cambria_banner_metabox_body', $register_type_name, 'normal');
}

/**
 * メタボックスで表示する本体
 * @uses switch_lang()
 */
function st_cambria_banner_metabox_body() {
	global $post;
	wp_nonce_field( 'banner_action', 'banner_nonce' );?>
	<form class="url-and-caption" method="post">
		<p>URL</p>
		<input type="url" name="url" value="<?php echo esc_url(get_post_meta($post->ID, 'url', true)); ?>" class="regular-text">
		<p>Caption</p>
		<input type="text" name="caption" value="<?php echo esc_html(get_post_meta($post->ID, 'caption', true));?>" class="regular-text">
		<p></p>
		<label>
			<input type="checkbox" name="target" value="1" <?php echo esc_html(get_post_meta( $post->ID, 'target', true )); ?>>
			<?php switch_lang('リンクを新ウィンドウまたはタブで開く', ' Open link in a new window/tab'); ?>
		</label>
	</form>
<?php
}

/** 
 * 更新された時の処理
 * @uses $register_type_name
 */
function st_cambria_update_banner_meta() {
	global $post, $register_type_name;
	if ( !empty($_POST) and get_post_type($_POST['post_ID']) == $register_type_name and check_admin_referer('banner_action', 'banner_nonce') ) :

		$chk_target = ( isset($_POST['target']) ) ? 'checked' : '';
		update_post_meta( $post->ID, 'url', esc_url($_POST['url']) );
		update_post_meta( $post->ID, 'caption', esc_html($_POST['caption']) );
		update_post_meta( $post->ID, 'target', $chk_target );
	endif;
}

/**
 * バナーの出力
 * @uses $register_type_name
 * @return display HTML ul content
 */
if ( ! function_exists('banners') ):
function banners(){
	global $post, $register_type_name;

	$banners = new WP_Query(array(
		'post_type'      => $register_type_name,
		'posts_per_page' => -1,
		'order'          => 'ASC',
		'orderby'        => 'menu_order',
		));
	
	if ( $banners -> have_posts() ): 
		echo '<ul class="banners">';
		while ($banners -> have_posts()): $banners -> the_post();

			if ( get_the_post_thumbnail() ):
				$img     = get_the_post_thumbnail( $post->ID, 'banner' );
				$url     = get_post_meta($post->ID, 'url', true);
				$caption = get_post_meta($post->ID, 'caption', true);
				$target  = ( get_post_meta($post->ID, 'target', true) == 'checked' )? '_blank' : '_self';

				echo '<li class="banner-item"><a href="'.$url.'" target="'.$target.'">'.$img.'</a><span class="banner-caption">'.$caption.'</span></li>';
			endif;

		endwhile;
		echo '</ul>';
	endif;

	wp_reset_postdata();
}
endif; // check function_exists

?>