/**
 * TinyMCEにセレクトメニューを追加
 *
 * @link http://www.tinymce.com/tryit/menubutton.php
 * @link http://www.wpactions.com/1028/how-to-create-dropdown-list-button-in-tinymce-toolbar/
 * @link http://stackoverflow.com/questions/22684464/shortcode-dropdown-box-in-tinymce-is-not-working-in-wordpress-3-9
 * @link http://memocarilog.info/wordpress/6227
 */

(function() {
	tinymce.create('tinymce.plugins.add_shortcodes', {
		init : function(ed, url){

			/**
			 * ショートコードを挿入するセレクトメニューを作る
			 */
			// 編集画面に追加するショートコードのリストを作る
			var shortcodesList = [
				{
					text   : 'Archive',
					onclick: function(){ed.insertContent('[archive posts_per_page=\"-1\"]')},
				},
				{
					text   : 'List pages',
					onclick: function(){ed.insertContent('[list-pages]')},
				},
				{
					text   : 'Sitemap',
					onclick: function(){ed.insertContent('[sitemap]')},
				},
				{
					text   : 'Button',
					onclick: function(){ed.insertContent('[button url=" " text=" " open="self or other"]')},
				}
			];

			// 作成したリストをボタンとして登録
			ed.addButton('shortcode', {
				type: 'menubutton',
				text: 'Shortcodes',
				icon: false,
				fixedWidth: true,
				menu: shortcodesList,
			});

			/**
			 * ボタン風リンクのon/offを行えるセレクトメニューを作る
			 */
			// onとoffをクリックした際の動作をリストで作成
			var actionsList =[
				{
					text    : 'add Button',
					onclick : function(){
						var target = tinyMCE.activeEditor.dom.getParent(tinyMCE.activeEditor.selection.getNode());
						if ( target.tagName == 'A' ) {
							tinyMCE.activeEditor.dom.addClass(target, 'button');
						};
					}, // onclick
				},
				{
					text    : 'remove Button',
					onclick : function(){
						var target = tinyMCE.activeEditor.dom.getParent(tinyMCE.activeEditor.selection.getNode());
						if ( target.tagName == 'A' ) {
							tinyMCE.activeEditor.dom.removeClass(target, 'button');
						};
					},  // onclick
				},
			];

			// 作成したリストでボタンを作成
			ed.addButton('button_link',{
				type: 'menubutton',
				text: 'Button Link',
				icon: false,
				fixedWidth: true,
				menu: actionsList,
			}); // addButton end


			/**
			 * tableタグにclassをつける
			 */
			// リストを作成
			var tableClassList =[
				{
					text    : 'Normal',
					onclick : function(){addClassToTable('');},
				},
				{
					text    : 'table-1',
					onclick : function(){addClassToTable('table-1');},
				},
				{
					text    : 'table-2',
					onclick : function(){addClassToTable('table-2');},
				},
				{
					text    : 'table-3',
					onclick : function(){addClassToTable('table-3');},
				},
				{
					text    : 'table-4',
					onclick : function(){addClassToTable('table-4');},
				},
			];

			// 作成したリストでボタンを作成
			ed.addButton('tables',{
				type: 'menubutton',
				text: 'Tables',
				icon: false,
				fixedWidth: true,
				menu: tableClassList,
			}); // addButton end

		}, // init end

		getInfo : function(){
			return {
				longname  : 'Add Custom Listbox',
				author    : 'Space-Time Inc.',
				authorurl : 'http://stxst.com',
				infourl   : 'http://stxst.com',
				version   : '1.0'
			};
		} // getInfo end
	});

	// クリックされた要素の親を遡り、tableタグを探す
	// tableタグ以外には何もしない
	function addClassToTable( ClassName ){
		var ancestors = tinyMCE.activeEditor.dom.getParents(tinyMCE.activeEditor.selection.getNode());

		for (var i = 0; i < ancestors.length; i++) {
			if ( ancestors[i].tagName == 'TABLE' ) { 
				tinyMCE.activeEditor.dom.removeClass(ancestors[i], 'table-1');
				tinyMCE.activeEditor.dom.removeClass(ancestors[i], 'table-2');
				tinyMCE.activeEditor.dom.removeClass(ancestors[i], 'table-3');
				tinyMCE.activeEditor.dom.removeClass(ancestors[i], 'table-4');
				tinyMCE.activeEditor.dom.addClass(ancestors[i], ClassName);
			};
		};
	}; // addClassToTable() end

	tinymce.PluginManager.add('shortcode', tinymce.plugins.add_shortcodes);
})();