<?php
/**
 * button links
 */
function shortcode_button_link($atts) {
	extract(shortcode_atts(array(
		'url'    => home_url(),
		'text'   => 'button',
		'open'   => 'other',
	), $atts));

	$str = '';

	$target = ( $open == 'self' ) ? '_self' : '_blank';
	$str .= '<a class="button" href="'.$url.'" target="'.$target.'">'.$text.'</a>';

	return $str;
}
add_shortcode( 'button', 'shortcode_button_link' );

/**
 * list child pages
 */
function shortcode_list_pages() {
	global $post;
	$str  = '';
	$str .= '<ul class="list-pages">';
	$str .= wp_list_pages(array(
		'child_of'   => $post->ID,
		'title_li'   => '',
		'sort_culum' => 'menu_order',
		'echo'       => false,
		));
	$str .= '</ul>';

	return $str;
}
add_shortcode( 'list-pages', 'shortcode_list_pages' );


/**
 * sitemap (list all pages)
 */
function shortcode_sitemap() {
	$str  = '';
	$str .= '<ul class="sitemap">';
	$str .= wp_list_pages(array(
		'title_li'   => '',
		'sort_culum' => 'menu_order',
		'echo'       => false,
		));
	$str .= '</ul>';

	return $str;
}
add_shortcode( 'sitemap', 'shortcode_sitemap' );


/**
 * list all posts
 */
function shortcode_post_archive($atts) {
	extract(shortcode_atts(array(
		'posts_per_page' => -1,
	), $atts));
	global $post;

	$str      = '';
	$paged    = (get_query_var('paged')) ? get_query_var('paged') : 1;
	$wp_query = new WP_Query(array(
		'post_type'      => 'post',
		'posts_per_page' => $posts_per_page,
		'paged'          => $paged,
		));

	ob_start();

	if ($wp_query -> have_posts()):
		while ($wp_query -> have_posts()): $wp_query -> the_post();
			get_template_part( '/template-parts/list-view');
		endwhile;
	endif;

	if ( $wp_query->max_num_pages >= 2 and ! is_front_page() ) : ?>
		<nav class="navigation posts-navigation" role="navigation">
			<h2 class="screen-reader-text"><?php esc_html_e( 'Posts navigation', 'active-learning' ); ?></h2>
			<div class="nav-links">

				<?php if ( get_next_posts_link('過去の投稿', $wp_query->max_num_pages) ) : ?>
					<div class="nav-previous"><?php next_posts_link('過去の投稿', $wp_query->max_num_pages); ?></div>
				<?php endif; ?>

				<?php if ( get_previous_posts_link('新しい投稿', $wp_query->max_num_pages) ) : ?>
					<div class="nav-next"><?php previous_posts_link('新しい投稿', $wp_query->max_num_pages); ?></div>
				<?php endif; ?>

			</div><!-- .nav-links -->
		</nav><!-- .navigation -->
	<?php
	endif;


	wp_reset_postdata();
	wp_reset_query();

	$str .= ob_get_clean();
	return $str;
}
add_shortcode( 'archive', 'shortcode_post_archive' );

/**
 * url [url] 
 */
function shortcode_url() {
    return get_bloginfo('url');
}
add_shortcode('url', 'shortcode_url');



/**
 * WYSIWYGのアイコン欄からセレクトメニューを追加して、ショートコードを利用できるように。
 *
 * WordPress 3.9以上に対応。TinyMCE 4以上が必要なため。
 * 「TinyMCEのプラグインをつくる → WordPressで使えるようにする」の流れ。
 * TinyMCEのプラグインはjs。{@link http://www.tinymce.com/wiki.php}
 *
 * @link http://www.wpactions.com/1028/how-to-create-dropdown-list-button-in-tinymce-toolbar/
 * @link http://stackoverflow.com/questions/22684464/shortcode-dropdown-box-in-tinymce-is-not-working-in-wordpress-3-9
 */
add_action('init', 'add_buttons');

// tinymceにボタンを追加
function add_buttons() {
	// ユーザー権限を確認
	if ( ! current_user_can('edit_posts') && ! current_user_can('edit_pages') ) return;

	// wp-admin/profile.phpで「ビジュアルエディター」にチェクを入れているか確認
	if ( get_user_option('rich_editing') == 'true') :
		add_filter("mce_external_plugins", 'path_to_plugin_js_file');
		add_filter('mce_buttons_3', 'shortcodes_listbbox'); // mce_buttons_3は編集画面のアイコンの3行目
	endif;
}

// プラグインファイルに関する情報
// ボタンの設定はjsでコントロール
function path_to_plugin_js_file($plugin_array) {
	$plugin_array['shortcode'] = get_template_directory_uri() . '/inc/shortcodes/add-shortcodes.js';
	return $plugin_array;
}

// jsで作ったボタンを登録
function shortcodes_listbbox($buttons) {
	array_push($buttons, "shortcode" ); // 第二引数に作ったボタン名
	array_push($buttons, "button_link" ); // 第二引数に作ったボタン名
	array_push($buttons, "tables" ); // 第二引数に作ったボタン名
	return $buttons;
}
