<?php
/**
 * テーマオプション画面のスラッグ
 */
$slug = 'theme_options';

/**
 * 画像のアップロードはjQueryで行うので、そのファイルの登録
 *
 * @uses $slug
 */
add_action( 'admin_enqueue_scripts', 'theme_option_media_enqueue' );
function theme_option_media_enqueue($hook) {
	global $slug;
	if ( isset($_GET['page']) && $_GET['page'] == $slug ):
		wp_enqueue_script('jquery');
		wp_enqueue_media();
		wp_enqueue_script( 'my_custom_script', get_template_directory_uri() . '/inc/theme-options/media-upload.js' );
	endif;
}

/**
 * .icoの拡張子も扱えるように
 */
add_filter('upload_mimes', 'add_mime_type_ico');
function add_mime_type_ico($mime){
	$mime['ico'] = 'image/x-icon';
	return $mime;
}

/**
 * 管理画面に、テーマオプションページを追加
 * 位置は、「外観」のサブメニュー
 *
 * @uses get_switch_lang()
 * @uses $slug
 */
add_action('admin_menu', 'add_options_menu');
function add_options_menu(){
	global $slug;
	add_theme_page(
		get_switch_lang('テーマオプション設定', 'Theme Options Setting'),
		get_switch_lang('テーマオプション', 'Theme Options'),
		'manage_options',
		$slug,
		'options_page_body'
	);
}

/**
 * テーマオプションページでの処理と本体HTML
 *
 * @uses switch_lang()
 */
function options_page_body(){

	// 更新された時の処理
	// check_admin_refere()は、wp_nonce_field()とセット
	if ( !empty($_POST) and check_admin_referer('theme_options', 'theme_options') ):

		// ロゴ画像がセットされていればテーブルを更新
		// $logo_idは整数として格納
		if ( !empty($_POST['logo_id']) ) :
			update_option( 'logo_id', intval($_POST['logo_id']) );
		else:
			delete_option('logo_id');
		endif;

		// パッケージ内CSSが指定されていればテーブルを更新
		// $packaged_cssは文字列として格納
		if ( !empty($_POST['packaged_css']) ) :
			update_option( 'packaged_css', esc_html($_POST['packaged_css']) );
		else:
			delete_option('packaged_css');
		endif;

		// 言語切り替えスイッチを表示するか否か
		// $use_lang_switchは整数として格納
		if ( !empty($_POST['use_lang_switch']) ) :
			update_option( 'use_lang_switch', intval($_POST['use_lang_switch']) );
		else:
			delete_option('use_lang_switch');
		endif;

		// ファビコンがセットされていればテーブルを更新
		// $favicon_idは整数として格納
		if ( !empty($_POST['favicon_id']) ) :
			update_option( 'favicon_id', intval($_POST['favicon_id']) );
		else:
			delete_option('favicon_id');
		endif;

		// トラッキングIDがセットされていればテーブルを更新
		// $tracking_idは文字列として格納
		if ( !empty($_POST['tracking_id']) ) :
			update_option( 'tracking_id', esc_html($_POST['tracking_id']) );
		else:
			delete_option('tracking_id');
		endif;

		// フッターテキストがセットされていればテーブルを更新
		// $footer_addressはテキストエリアとして格納
		if ( !empty($_POST['footer_address']) ) :
			update_option( 'footer_address', esc_textarea($_POST['footer_address']) );
		else:
			delete_option('footer_address');
		endif;

		// コピーライトがセットされていればテーブルを更新
		// $copyright_textは文字列として格納
		if ( !empty($_POST['copyright_text']) ) :
			update_option( 'copyright_text', esc_html($_POST['copyright_text']) );
		else:
			delete_option('copyright_text');
		endif;

	endif;


	// 現在の情報を取得
	// 各値は適切にエスケープ
	$cur_logo_id     = ( get_option('logo_id') ) ? intval(get_option('logo_id')) : null ;
	$cur_css_name    = ( get_option('packaged_css') ) ? esc_html(get_option('packaged_css')) : null ;
	$cur_use_switch  = ( get_option('use_lang_switch') ) ? 'checked="checked"' : null ;
	$cur_favicon_id  = ( get_option('favicon_id') ) ? intval(get_option('favicon_id')) : null ;
	$cur_tracking_id = ( get_option('tracking_id') ) ? esc_html(get_option('tracking_id')) : null ;
	$cur_address     = ( get_option('footer_address') ) ? esc_textarea(get_option('footer_address')) : null ;
	$cur_copyright   = ( get_option('copyright_text') ) ? esc_html(get_option('copyright_text')) : null ;
	?>

	<div class="wrap">
		<?php if ( ! empty($_POST) ):?>
			<div class="updated fade"><p><strong><?php switch_lang('設定を保存しました。', 'Options saved.'); ?></strong></p></div>
		<?php endif; ?>

		<h2><?php switch_lang('テーマオプション設定', 'Theme Options Settings'); ?></h2>

		<form method="post">
			<?php wp_nonce_field('theme_options', 'theme_options'); ?>
			<table class="form-table">
				<tr>
					<th><?php switch_lang('ロゴ', 'Logo'); ?></th>
					<td id="theme-logo">
						<div class="img-preview" style="margin-bottom:1em;">
							<?php
							if ( isset($cur_logo_id) ) :
								echo wp_get_attachment_image($cur_logo_id, 'large');
							else:
								switch_lang('画像が設定されていません。', 'no image');
							endif; ?>
						</div><!-- preview -->

						<input class="img-id" type="hidden" name="logo_id" value="<?php echo $cur_logo_id; ?>">
						<input type="button" name="media" value="<?php switch_lang('選択', 'Select'); ?>" class="button">
						<input type="button" name="media-clear" value="<?php switch_lang('クリア', 'Clear'); ?>" class="button">
					</td>
				</tr>
				<tr>
					<th><?php switch_lang('パッケージ内CSS', 'Packaged CSS'); ?></th>
					<td>
						<fieldset>
							<legend class="screen-reader-text"><span><?php switch_lang('パッケージ内CSS', 'Packaged'); ?></span></legend>

							<?php
							$packages = array(
								'pikaia' => array(
									'value'    => 'pikaia',
									'label_jp' => 'Pikaia (シンプルでフラットなデザイン)',
									'label_en' => 'Pikaia (Simple and Flat Design)',
									),
								'hallucigenia' => array(
									'value'    => 'hallucigenia',
									'label_jp' => 'Hallucigenia (グラデーションを用いたリッチなデザイン)',
									'label_en' => 'Hallucigenia (Rich design with gradients)',
									),
									'cambropachycope' => array(
										'value'    => 'cambropachycope',
										'label_jp' => 'cambropachycope (1カラム用-カンブロパキコーペ)',
										'label_en' => 'cambropachycope (One column)',
										),
								'not-selected' => array(
									'value'    => 'not-selected',
									'label_jp' => '使用しない',
									'label_en' => 'Do not use',
									),
								);

							foreach ($packages as $package) :
								$checked = ( $cur_css_name == $package['value'] ) ? 'checked="checked"' : '';
							?>
								<label title="<?php echo $package['value']; ?>">
									<input type="radio" name="packaged_css" value="<?php echo $package['value']; ?>" <?php echo $checked; ?>></input><?php switch_lang($package['label_jp'], $package['label_en']); ?>
								</label>
								<br />
							<?php
							endforeach;
							?>
						</fieldset>
					</td>
				</tr>
				<tr>
					<th><?php switch_lang('言語切り替えリンク', 'Language switching Link'); ?></th>
					<td>
						<fieldset>
							<legend class="screen-reader-text"><span><?php switch_lang('言語切り替え', 'Language switching'); ?></span></legend>
							<label for="use_lang_switch">
								<input type="checkbox" name="use_lang_switch" id="use_lang_switch" value="1" <?php echo $cur_use_switch; ?>><?php switch_lang('サイトヘッダーから日英のリンクを削除', 'Remove Japanese-English link from the site header'); ?>
							</label>
						</fieldset>
					</td>
				</tr>
				<tr>
					<th><?php switch_lang('ファビコン', ' Favicon'); ?></th>
					<td id="theme-favicon">
						<div class="img-preview" style="margin-bottom:1em;">
							<?php
							if ( isset($cur_favicon_id) ) :
								$favicon = wp_get_attachment_image_src($cur_favicon_id, 'large');
								echo '<img src="'.$favicon[0].'">';
							else:
								switch_lang('画像が設定されていません。', 'no image');
							endif; ?>
						</div><!-- preview -->

						<input class="img-id" type="hidden" name="favicon_id" value="<?php echo $cur_favicon_id; ?>">
						<input type="button" name="media" value="<?php switch_lang('選択', 'Select'); ?>" class="button">
						<input type="button" name="media-clear" value="<?php switch_lang('クリア', 'Clear'); ?>" class="button">
					</td>
				</tr>
				<tr>
					<th><?php switch_lang('トラッキングID', 'Tracking ID'); ?></th>
					<td>
						<input type="text" name="tracking_id" class="regular-text" value="<?php echo $cur_tracking_id; ?>">
						<p><?php switch_lang('Google AnalyticsのトラッキングIDを入力してください。', 'Please enter the tracking ID of Google Analytics.'); ?></p>
					</td>
				</tr>
				<tr>
					<th><?php switch_lang('フッターアドレス', 'Footer Address'); ?></th>
					<td>
						<textarea name="footer_address" rows="10" cols="50" class="large-text code"><?php echo $cur_address; ?></textarea>
					</td>
				</tr>
				<tr>
					<th><?php switch_lang('コピーライト', 'Copyright'); ?></th>
					<td>
						<input type="text" name="copyright_text" class="regular-text" value="<?php echo $cur_copyright; ?>">
					</td>
				</tr>
				<tr>
					<th><?php switch_lang('メニュー', 'Menus'); ?></th>
					<td>
						<?php
						$nav_menus = wp_get_nav_menus(array('oderby' => 'ID', 'order' => 'DESC'));

						if ( !empty($nav_menus) ):
							echo '<p>'.get_switch_lang('編集するメニューを選択：', 'Select a menu to edit:').'</p>';
							foreach ($nav_menus as $key) :
								echo '<p><a href="'.admin_url('nav-menus.php?action=edit&menu=').$key->term_id.'">'.$key->name.'</a></p>';
							endforeach;
							// echo '</ul>';
						endif;
						?>

					</td>
				</tr>
			</table>

			<input type="submit" name="Submit" class="button button-primary" value="<?php switch_lang('変更を保存', 'Save Changes'); ?>" />
		</form>

	</div><!-- wrap -->
<?php
} // options_page_body



/**
 * セットしたオプションの出力
 */
class Theme_options{

	// ロゴ画像
	public function logo(){
		$logo = get_option('logo_id');
		echo ( $logo ) ? wp_get_attachment_image($logo, 'full') : get_bloginfo('name');
	}

	// 言語切り替えスイッチ
	public function use_lang_switch(){
		if ( ! get_option('use_lang_switch') ) : // 言語切り替えを表示するなら
			return true;
		else: // 削除したいなら
			return false;
		endif;
	}

	// ファビコン
	public function favicon(){
		if ( get_option('favicon_id') ):
			$src = wp_get_attachment_image_src(get_option('favicon_id'), 'full');
			echo '<link rel="shortcut icon" href="'.$src[0].'">';
		endif;
	}

	// 連絡先
	public function footer_address(){
		if ( get_option('footer_address') ):
			$address_array = explode("\n", get_option('footer_address'));

			echo '<ul class="footer-address">';
			foreach ($address_array as $line) :
				echo '<li>'.$line.'</li>';
			endforeach;
			echo '</ul>';
		endif;
	}

	// コピーライトテキスト
	public function copyright(){
		$text = get_option('copyright_text');
		echo ( $text ) ? $text : '';
	}

	// google tracking code
	public function tracking_code(){
		if ( get_option('tracking_id') ):?>
			<script>
			  (function(i,s,o,g,r,a,m){i['GoogleAnalyticsObject']=r;i[r]=i[r]||function(){
			  (i[r].q=i[r].q||[]).push(arguments)},i[r].l=1*new Date();a=s.createElement(o),
			  m=s.getElementsByTagName(o)[0];a.async=1;a.src=g;m.parentNode.insertBefore(a,m)
			  })(window,document,'script','//www.google-analytics.com/analytics.js','ga');

			  ga('create', <?php echo '\''.get_option('tracking_id').'\''; ?>, 'auto');
			  ga('send', 'pageview');

			</script>
	<?php
		endif;
	}
} // class end


/**
 * 選択されたパッケージ内CSSを、<head></head>内に挿入
 */
add_action( 'wp_enqueue_scripts', 'enqueue_packaged_css', 100 );
function enqueue_packaged_css() {
	$packaged_css = get_option('packaged_css');

	if ( $packaged_css != 'not-selected' ) :
		wp_enqueue_style( $packaged_css, get_template_directory_uri() . '/css/style-'.$packaged_css.'.css', 'style', '1.0' );
	endif;
}

/**
 * 管理画面のWYSIWYG用CSSの登録
 */
if ( get_option('packaged_css') != 'not-selected' ) :
	$css_path = get_template_directory_uri() . '/css/editor-' . get_option('packaged_css') . '.css';
	add_editor_style( $css_path );
endif;
